## [AI3: Securing AI Assets with Web3 🤖🔐]((https://vigorous-drifter-f15.notion.site/687c447b0f3b4e28bb9112aec76e3d6a?v=50be9378461a4720b713f7012eff4906))

### Introduction 🚀

AI3 is a pioneering initiative aimed at safeguarding AI assets by leveraging the power of Web3 technology. 

One prominent AI company began as an open-source research entity but shifted to closed-source after significant success. Shortly after, it was acquired by a major corporation, granting them exclusive access to groundbreaking AI research originally intended for public benefit.

If a this happens again with the most popular AI website, which hosts over 20k open-source models, it would significantly impact the public capacity to compete with closed source AI. 

`In the near future we are all going to need AI just to stay competitive`

Therefore, it's crucial to transition all necessary assets to a permissionless, trustless, public, and immutable stage. Fortunately, Web3 technology provides the solution we need. 🌐🛡️

### The Problem: Centralization ❌

The centralization of AI assets presents a formidable challenge to the open exchange of knowledge and innovation.This calls for the urgent need for decentralized solutions to safeguard AI assets for the collective benefit of the global community.

`There are more than 20k high quality opensource models`

`How can we decentralize them?`

### Leveraging Web3 Technology 🌐

Web3 technology, with its principles of permissionless access, trustlessness, public verifiability, and immutability, emerges as a beacon of hope in addressing the challenges posed by centralized AI assets. By harnessing the decentralized nature of Web3, AI3 seeks to democratize access to AI resources, ensuring that crucial research and models remain accessible to all stakeholders.

### Tech Stack 💻

AI3 utilizes a robust tech stack, combining industry-standard tools and cutting-edge technologies:

- **Python**: The library is developed in Python, a widely adopted programming language known for its simplicity and versatility. Targeted at AI engineers, ML engineers, data scientists, and MLOps engineers, Python ensures broad accessibility and ease of use.

- **TensorFlow**: TensorFlow, a powerful open-source machine learning library developed by Google, serves as the backbone of AI3. With TensorFlow, users can perform a myriad of AI tasks, including training, inference, transfer learning, and model management.

- **IPFS (InterPlanetary File System)**: IPFS, a decentralized storage system, is integrated into AI3 for storing and retrieving machine learning models. By leveraging IPFS, AI3 ensures that models are stored in a distributed manner, enhancing resilience and accessibility.

### Getting Started 🚀

To begin using AI3, follow these simple steps:

1. **Clone the Repository**: Clone the AI3 repository to your local machine using Git.
   
   ```bash
   git clone https://github.com/carlosarturoceron/ai3
   ```

2. **Build and Install the Library**: Navigate to the cloned directory and build the library using Python's package management tools.
   
   ```bash
   cd ai3
   python -m build
   pip install ai3-0.0.0-py3-none-any.whl
   ```

3. **Install Dependencies**: Ensure all required dependencies are installed using pip.
   
   ```bash
   pip install -r requirements.txt
   ```

4. **Load and Utilize Models**: Load AI models from the AI3 library and perform various tasks such as inference, prediction, and fine-tuning.
   
   ```python
   from ai3.models import spamDetection
   model = spamDetection.load()
   print(model.summary())
   ```

### Addressing the Centralization Challenge 🎯

The centralization of AI assets poses a significant barrier to innovation and equitable access. AI3 endeavors to address this challenge by democratizing access to AI resources through decentralized solutions. By embracing Web3 technology and fostering a collaborative ecosystem, AI3 aims to empower individuals, organizations, and communities to harness the full potential of AI for the betterment of society.

### Join the Decentralization Movement 🌍

The decentralization of AI assets is not merely a technological endeavor but a collective pursuit of knowledge and empowerment. Join us in our mission to safeguard AI resources and foster a more inclusive and equitable AI ecosystem. Together, we can unlock the transformative power of AI for the benefit of all humankind.

For more information and contributions, visit [AI3 GitHub Repository](https://github.com/carlosarturoceron/ai3).

### Available Assets

| Model         | Frameworks                                   | Task                | Author     | cid                                    |
|---------------|----------------------------------------------|---------------------|------------|----------------------------------------|
| spamDetection | TensorFlow2, TensorFlowLite, TFJS            | Text Classification | TensorFlow | bafybeibpfidw6stsf3leqj3af3wskx7bzjahiifbuny2adofhk |
| imageNet      | TensorFlow2, TensorFlowLite, TFJS            | Image Feature Vector, Image Classification | TensorFlow | bafybei6rfobjb3r7wha56qo3a6yullryafcdtg2ipz5rxi5azj |

## Future Works 🚧🔮

As we continue to build and improve AI3, we are excited about the road ahead. Our vision for the future involves several key initiatives:

API to archive AI assets: bulding an API method that allows users to easly archive their work in to web3 storage services.

Adding redundant storage service providers: Filecoin, Arweave, and other clients to increase duplication.

Expansion of Model Library 📚: We will broaden our selection of open-source models, covering a wider array of AI applications to support and stimulate innovation across different fields.

Enhanced Decentralization Features 🌐: By integrating more robust decentralized features such as DAO governance, we aim to put the power of AI development and distribution into the hands of the community.

Interoperability Protocols 🤝: We are committed to enhancing the interoperability among diverse AI models and various blockchain platforms to create a more unified and powerful ecosystem.

Educational Programs 🎓: To empower more individuals to contribute to and benefit from AI and Web3, we will launch educational initiatives, providing resources and learning opportunities for all skill levels.

Community Building 👥: A strong, vibrant community is the backbone of any decentralized project. We will organize events like hackathons, workshops, and forums to nurture a collaborative environment.

The journey towards a decentralized AI future is full of potential, and your contributions are invaluable.

🌟 Join the AI3 community and be a part of the movement that shapes the future of decentralized AI. 🌟